@@ -16,8 +16,6 @@ from datetime import datetime
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
-from botocore.paginate import Paginator as Boto3Paginator
 
 from mypy_boto3_kinesisanalyticsv2.paginator import (
     ListApplicationSnapshotsPaginator,
@@ -68,26 +66,34 @@ else:
 __all__ = ("KinesisAnalyticsV2Client",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    CodeValidationException: Type[Boto3ClientError]
-    ConcurrentModificationException: Type[Boto3ClientError]
-    InvalidApplicationConfigurationException: Type[Boto3ClientError]
-    InvalidArgumentException: Type[Boto3ClientError]
-    InvalidRequestException: Type[Boto3ClientError]
-    LimitExceededException: Type[Boto3ClientError]
-    ResourceInUseException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
-    ResourceProvisionedThroughputExceededException: Type[Boto3ClientError]
-    ServiceUnavailableException: Type[Boto3ClientError]
-    TooManyTagsException: Type[Boto3ClientError]
-    UnableToDetectSchemaException: Type[Boto3ClientError]
-    UnsupportedOperationException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    CodeValidationException: Type[BotocoreClientError]
+    ConcurrentModificationException: Type[BotocoreClientError]
+    InvalidApplicationConfigurationException: Type[BotocoreClientError]
+    InvalidArgumentException: Type[BotocoreClientError]
+    InvalidRequestException: Type[BotocoreClientError]
+    LimitExceededException: Type[BotocoreClientError]
+    ResourceInUseException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
+    ResourceProvisionedThroughputExceededException: Type[BotocoreClientError]
+    ServiceUnavailableException: Type[BotocoreClientError]
+    TooManyTagsException: Type[BotocoreClientError]
+    UnableToDetectSchemaException: Type[BotocoreClientError]
+    UnsupportedOperationException: Type[BotocoreClientError]
 
 
 class KinesisAnalyticsV2Client:
     """
-    [KinesisAnalyticsV2.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client)
+    [KinesisAnalyticsV2.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client)
     """
 
     meta: ClientMeta
@@ -100,14 +106,14 @@ class KinesisAnalyticsV2Client:
         CloudWatchLoggingOption: CloudWatchLoggingOptionTypeDef,
     ) -> AddApplicationCloudWatchLoggingOptionResponseTypeDef:
         """
-        [Client.add_application_cloud_watch_logging_option documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_cloud_watch_logging_option)
+        [Client.add_application_cloud_watch_logging_option documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_cloud_watch_logging_option)
         """
 
     def add_application_input(
         self, ApplicationName: str, CurrentApplicationVersionId: int, Input: "InputTypeDef"
     ) -> AddApplicationInputResponseTypeDef:
         """
-        [Client.add_application_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input)
+        [Client.add_application_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input)
         """
 
     def add_application_input_processing_configuration(
@@ -118,14 +124,14 @@ class KinesisAnalyticsV2Client:
         InputProcessingConfiguration: "InputProcessingConfigurationTypeDef",
     ) -> AddApplicationInputProcessingConfigurationResponseTypeDef:
         """
-        [Client.add_application_input_processing_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input_processing_configuration)
+        [Client.add_application_input_processing_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input_processing_configuration)
         """
 
     def add_application_output(
         self, ApplicationName: str, CurrentApplicationVersionId: int, Output: "OutputTypeDef"
     ) -> AddApplicationOutputResponseTypeDef:
         """
-        [Client.add_application_output documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_output)
+        [Client.add_application_output documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_output)
         """
 
     def add_application_reference_data_source(
@@ -135,7 +141,7 @@ class KinesisAnalyticsV2Client:
         ReferenceDataSource: "ReferenceDataSourceTypeDef",
     ) -> AddApplicationReferenceDataSourceResponseTypeDef:
         """
-        [Client.add_application_reference_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_reference_data_source)
+        [Client.add_application_reference_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_reference_data_source)
         """
 
     def add_application_vpc_configuration(
@@ -145,12 +151,12 @@ class KinesisAnalyticsV2Client:
         VpcConfiguration: "VpcConfigurationTypeDef",
     ) -> AddApplicationVpcConfigurationResponseTypeDef:
         """
-        [Client.add_application_vpc_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_vpc_configuration)
+        [Client.add_application_vpc_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_vpc_configuration)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.can_paginate)
         """
 
     def create_application(
@@ -164,75 +170,75 @@ class KinesisAnalyticsV2Client:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateApplicationResponseTypeDef:
         """
-        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application)
+        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application)
         """
 
     def create_application_snapshot(
         self, ApplicationName: str, SnapshotName: str
     ) -> Dict[str, Any]:
         """
-        [Client.create_application_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_snapshot)
+        [Client.create_application_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_snapshot)
         """
 
     def delete_application(self, ApplicationName: str, CreateTimestamp: datetime) -> Dict[str, Any]:
         """
-        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application)
+        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application)
         """
 
     def delete_application_cloud_watch_logging_option(
         self, ApplicationName: str, CurrentApplicationVersionId: int, CloudWatchLoggingOptionId: str
     ) -> DeleteApplicationCloudWatchLoggingOptionResponseTypeDef:
         """
-        [Client.delete_application_cloud_watch_logging_option documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_cloud_watch_logging_option)
+        [Client.delete_application_cloud_watch_logging_option documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_cloud_watch_logging_option)
         """
 
     def delete_application_input_processing_configuration(
         self, ApplicationName: str, CurrentApplicationVersionId: int, InputId: str
     ) -> DeleteApplicationInputProcessingConfigurationResponseTypeDef:
         """
-        [Client.delete_application_input_processing_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_input_processing_configuration)
+        [Client.delete_application_input_processing_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_input_processing_configuration)
         """
 
     def delete_application_output(
         self, ApplicationName: str, CurrentApplicationVersionId: int, OutputId: str
     ) -> DeleteApplicationOutputResponseTypeDef:
         """
-        [Client.delete_application_output documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_output)
+        [Client.delete_application_output documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_output)
         """
 
     def delete_application_reference_data_source(
         self, ApplicationName: str, CurrentApplicationVersionId: int, ReferenceId: str
     ) -> DeleteApplicationReferenceDataSourceResponseTypeDef:
         """
-        [Client.delete_application_reference_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_reference_data_source)
+        [Client.delete_application_reference_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_reference_data_source)
         """
 
     def delete_application_snapshot(
         self, ApplicationName: str, SnapshotName: str, SnapshotCreationTimestamp: datetime
     ) -> Dict[str, Any]:
         """
-        [Client.delete_application_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_snapshot)
+        [Client.delete_application_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_snapshot)
         """
 
     def delete_application_vpc_configuration(
         self, ApplicationName: str, CurrentApplicationVersionId: int, VpcConfigurationId: str
     ) -> DeleteApplicationVpcConfigurationResponseTypeDef:
         """
-        [Client.delete_application_vpc_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_vpc_configuration)
+        [Client.delete_application_vpc_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_vpc_configuration)
         """
 
     def describe_application(
         self, ApplicationName: str, IncludeAdditionalDetails: bool = None
     ) -> DescribeApplicationResponseTypeDef:
         """
-        [Client.describe_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application)
+        [Client.describe_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application)
         """
 
     def describe_application_snapshot(
         self, ApplicationName: str, SnapshotName: str
     ) -> DescribeApplicationSnapshotResponseTypeDef:
         """
-        [Client.describe_application_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_snapshot)
+        [Client.describe_application_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_snapshot)
         """
 
     def discover_input_schema(
@@ -244,7 +250,7 @@ class KinesisAnalyticsV2Client:
         InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = None,
     ) -> DiscoverInputSchemaResponseTypeDef:
         """
-        [Client.discover_input_schema documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.discover_input_schema)
+        [Client.discover_input_schema documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.discover_input_schema)
         """
 
     def generate_presigned_url(
@@ -255,48 +261,48 @@ class KinesisAnalyticsV2Client:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.generate_presigned_url)
         """
 
     def list_application_snapshots(
         self, ApplicationName: str, Limit: int = None, NextToken: str = None
     ) -> ListApplicationSnapshotsResponseTypeDef:
         """
-        [Client.list_application_snapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_snapshots)
+        [Client.list_application_snapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_snapshots)
         """
 
     def list_applications(
         self, Limit: int = None, NextToken: str = None
     ) -> ListApplicationsResponseTypeDef:
         """
-        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_applications)
+        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_applications)
         """
 
     def list_tags_for_resource(self, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_tags_for_resource)
         """
 
     def start_application(
         self, ApplicationName: str, RunConfiguration: RunConfigurationTypeDef
     ) -> Dict[str, Any]:
         """
-        [Client.start_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.start_application)
+        [Client.start_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.start_application)
         """
 
     def stop_application(self, ApplicationName: str) -> Dict[str, Any]:
         """
-        [Client.stop_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.stop_application)
+        [Client.stop_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.stop_application)
         """
 
     def tag_resource(self, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.untag_resource)
         """
 
     def update_application(
@@ -309,7 +315,7 @@ class KinesisAnalyticsV2Client:
         CloudWatchLoggingOptionUpdates: List[CloudWatchLoggingOptionUpdateTypeDef] = None,
     ) -> UpdateApplicationResponseTypeDef:
         """
-        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application)
+        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application)
         """
 
     @overload
@@ -317,7 +323,7 @@ class KinesisAnalyticsV2Client:
         self, operation_name: Literal["list_application_snapshots"]
     ) -> ListApplicationSnapshotsPaginator:
         """
-        [Paginator.ListApplicationSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplicationSnapshots)
+        [Paginator.ListApplicationSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplicationSnapshots)
         """
 
     @overload
@@ -325,8 +331,5 @@ class KinesisAnalyticsV2Client:
         self, operation_name: Literal["list_applications"]
     ) -> ListApplicationsPaginator:
         """
-        [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplications)
+        [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplications)
         """
-
-    def get_paginator(self, operation_name: str) -> Boto3Paginator:
-        pass
