@@ -18,6 +18,8 @@ if sys.version_info >= (3, 8):
 else:
     from typing_extensions import Literal
 
+import sys
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -207,7 +209,7 @@ _RequiredApplicationDetailTypeDef = TypedDict(
         "ApplicationName": str,
         "RuntimeEnvironment": Literal["SQL-1_0", "FLINK-1_6", "FLINK-1_8"],
         "ApplicationStatus": Literal[
-            "DELETING", "STARTING", "STOPPING", "READY", "RUNNING", "UPDATING"
+            "DELETING", "STARTING", "STOPPING", "READY", "RUNNING", "UPDATING", "AUTOSCALING"
         ],
         "ApplicationVersionId": int,
     },
@@ -271,7 +273,7 @@ ApplicationSummaryTypeDef = TypedDict(
         "ApplicationName": str,
         "ApplicationARN": str,
         "ApplicationStatus": Literal[
-            "DELETING", "STARTING", "STOPPING", "READY", "RUNNING", "UPDATING"
+            "DELETING", "STARTING", "STOPPING", "READY", "RUNNING", "UPDATING", "AUTOSCALING"
         ],
         "ApplicationVersionId": int,
         "RuntimeEnvironment": Literal["SQL-1_0", "FLINK-1_6", "FLINK-1_8"],
@@ -851,7 +853,10 @@ class ReferenceDataSourceUpdateTypeDef(
 
 RunConfigurationDescriptionTypeDef = TypedDict(
     "RunConfigurationDescriptionTypeDef",
-    {"ApplicationRestoreConfigurationDescription": "ApplicationRestoreConfigurationTypeDef"},
+    {
+        "ApplicationRestoreConfigurationDescription": "ApplicationRestoreConfigurationTypeDef",
+        "FlinkRunConfigurationDescription": "FlinkRunConfigurationTypeDef",
+    },
     total=False,
 )
 
